==> 0.0.3.tar.gz: lib/simple_connect.dart <==
import 'package:connectivity/connectivity.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:http/http.dart';
import 'dart:convert';
import 'dart:io';

import 'package:progress_dialog/progress_dialog.dart';

enum requestType {
  get,
  post,
  put,
  delete
}

enum errorType{
  empty,
  internet,
  auth,
  unknown
}

class CleanConnect{
  static String _mainUrl = '';
  static Map<String, String> _header = {"Content-Type": "application/json"};
  static List<int> _statusSuccess = [200, 201, 202];
  static ProgressDialog _progressDialog;
  static String _language = 'pt';
  static Map<String, Map<String, Map<String, String>>> _errors = {
    'en' : {
      'internet' : {
        'title' : 'Connection',
        'context' : 'No Internet Access'
      },
      'unknown' : {
        'title' : 'Error',
        'content' : 'Unexpected error'
      },
      'auth' : {
        'title' : 'Unauthorized',
        'content' : 'You are not authorized to access this information.'
      },
      'inputs' : {
        'btn-positive' : 'Try Again',
        'btn-negative' : 'Cancel'
      }
    },
    'pt' : {
      'internet' : {
        'title' : 'Erro de conexão',
        'context' : 'Verifique sua conexão com a internet e tente novamente!'
      },
      'unknown' : {
        'title' : 'Erro',
        'content' : 'Erro desconhecido, por favor, tente novamente!'
      },
      'auth' : {
        'title' : 'Não autorizado',
        'content' : 'Você não tem permissão para acessar essa informação.'
      },
      'inputs' : {
        'btn-positive' : 'Tentar novamente',
        'btn-negative' : 'Cancelar'
      }
    }
  };

  static cleanInit({@required BuildContext context, @required String mainUrl, String messageWhileLoading = 'Loading...'}){
    _progressDialog = new ProgressDialog(context, ProgressDialogType.Normal);
    _progressDialog.setMessage(messageWhileLoading);
    _mainUrl = mainUrl;
  }

  static bool setProgressDialogMessage(String message) {
    if (_progressDialog != null){
      _progressDialog.setMessage(message);
      return true;
    }return false;
  }

  static _setProgressStatus(bool useProgress, bool status){
    if(_progressDialog != null && useProgress){
      if(status)
        _progressDialog.show();
      else
        _progressDialog.hide();
    }
  }

  static bool getProgressDialogStatus(){
    if(_progressDialog != null){
      return _progressDialog.isShowing();
    }return false;
  }

  static setHeader({String contentType = "application/json", String authorization = "bearer"}){
    _header = {"Content-Type": contentType,
      HttpHeaders.authorizationHeader: authorization};
  }

  static setMainUrl(String _url){
    _mainUrl = _url;
  }

  static addGrantedStatusCode(int statusCode){
    _statusSuccess.add(statusCode);
  }

  static String _errorType(errorType type){
    switch(type){
      case errorType.empty: return null;
      case errorType.internet: return 'internet';
      case errorType.auth: return 'auth';
      case errorType.unknown: return 'unknown';
    }

    return null;
  }

  static Future<dynamic> _errorDialog(context, errorType type, data) async =>
      (await showDialog(
          context: context,
          barrierDismissible: false,
          builder: (context) => AlertDialog(
            title: Text(_errors[_language][_errorType(type)]['title']),
            content: Text(_errors[_language][_errorType(type)]['content']),
            actions: <Widget>[
              FlatButton(
                child: Text(_errors[_language]['inputs']['btn-positive']),
                onPressed: () {
                  Navigator.pop(context, {'return' : true});
                },
              ),
              FlatButton(
                child: Text(_errors[_language]['inputs']['btn-negative']),
                onPressed: () {
                  Navigator.pop(context, {'return' : false});
                },
              )
            ],
          )
      ));

  static Future<Rest> _checkWhileError({
                                        @required bool useDialogs,
                                        @required customDialogError,
                                        @required errorType type,
                                        @required data,
                                        @required requestType requestT,
                                        @required String route,
                                        @required BuildContext context,
                                        @required dynamic sBody,
                                        @required String otherMainUrl,
                                        @required bool useProgress,
                                        @required bool jsonDecode,
                                      }) async{

    Rest finalRest = Rest(false, 0, {}, error: type, errorData: data);

    if(useDialogs) {
      if((await customDialogError(type, data))){
        while(finalRest.error != errorType.empty){
          finalRest = await cRequest(type: requestT,
              route: route,
              context: context,
              sBody: sBody,
              otherMainUrl: otherMainUrl,
              useProgress: false,
              useDialogs: false,
              jsonDecode: jsonDecode);

          if(finalRest.error != errorType.empty){
            if(!(await customDialogError(type, data))){
              break;
            }
          }
        }
      }
    }

    return finalRest;
  }

  static Future<Rest> cRequest({
    @required requestType type,
    @required String route,
    @required BuildContext context,
    dynamic sBody,
    String otherMainUrl,
    bool useProgress = true,
    bool useDialogs = true,
    bool jsonDecode = true,
    Future<bool> Function(errorType type, Object data) customDialogError
  }) async{

    Rest finalRest;
    _setProgressStatus(useProgress, true);
    customDialogError = customDialogError ?? (type, data) async => (await _errorDialog(context, type, data))['return'];

    if(await _checkConn()){
      finalRest = await (_getRequested(otherMainUrl ?? _mainUrl, route, type, sBody)
          .then((response) => Rest(_statusSuccess.contains(response.statusCode),
                                  response.statusCode,
                                  jsonDecode ? json.decode(response.body) : response.body)

      ).catchError((error) async => await _checkWhileError(
                                          useDialogs: useDialogs,
                                          customDialogError: customDialogError,
                                          type: errorType.unknown,
                                          data: error,
                                          requestT: type,
                                          route: route,
                                          context: context,
                                          sBody: sBody,
                                          otherMainUrl: otherMainUrl,
                                          useProgress: useProgress,
                                          jsonDecode: jsonDecode)
      ));
    }else{
      finalRest = await _checkWhileError(useDialogs: useDialogs,
                                          customDialogError: customDialogError,
                                          type: errorType.internet,
                                          data: {},
                                          requestT: type,
                                          route: route,
                                          context: context,
                                          sBody: sBody,
                                          otherMainUrl: otherMainUrl,
                                          useProgress: useProgress,
                                          jsonDecode: jsonDecode);
    }

    _setProgressStatus(useProgress, false);
    return finalRest;
  }

  static Future<Response> _getRequested(_mainUrl, _route, _type, _sBody) async {
    switch (_type) {
      case requestType.get:
        return await get('$_mainUrl$_route', headers: _header);

      case requestType.delete:
        return await delete('$_mainUrl$_route', headers: _header);

      case requestType.post:
        return await post('$_mainUrl$_route', headers: _header, body: json.encode(_sBody));

      case requestType.put:
        return await put('$_mainUrl$_route', headers: _header, body: json.encode(_sBody));

      default: return null;
    }
  }

  static Future<bool> _checkConn() async {
    final connectivityResult = await (Connectivity().checkConnectivity());
    return (connectivityResult == ConnectivityResult.mobile || connectivityResult == ConnectivityResult.wifi);
  }
}

class Rest{
  final bool success;
  final dynamic statusCode;
  final errorType error;
  final Object errorData;
  final dynamic data;

  Rest(this.success, this.statusCode, this.data, {this.error = errorType.empty, this.errorData});

  @override
  String toString() {
    return {'success': success, 'statusCode': statusCode, 'errorType' : error, 'data': data, 'errorData' : errorData}.toString();
  }
}

==> 0.0.4.tar.gz: lib/simple_connect.dart <==
import 'package:connectivity/connectivity.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:http/http.dart';
import 'dart:convert';
import 'dart:io';

import 'package:progress_dialog/progress_dialog.dart';

enum requestType {
  get,
  post,
  put,
  delete
}

enum errorType{
  empty,
  internet,
  auth,
  unknown
}

class CleanConnect{
  static String _mainUrl = '';
  static Map<String, String> _header = {"Content-Type": "application/json"};
  static List<int> _statusSuccess = [200, 201, 202];
  static ProgressDialog _progressDialog;
  static String _language = 'pt';
  static Map<String, Map<String, Map<String, String>>> _errors = {
    'en' : {
      'internet' : {
        'title' : 'Connection',
        'context' : 'No Internet Access'
      },
      'unknown' : {
        'title' : 'Error',
        'content' : 'Unexpected error'
      },
      'auth' : {
        'title' : 'Unauthorized',
        'content' : 'You are not authorized to access this information.'
      },
      'inputs' : {
        'btn-positive' : 'Try Again',
        'btn-negative' : 'Cancel'
      }
    },
    'pt' : {
      'internet' : {
        'title' : 'Erro de conexão',
        'context' : 'Verifique sua conexão com a internet e tente novamente!'
      },
      'unknown' : {
        'title' : 'Erro',
        'content' : 'Erro desconhecido, por favor, tente novamente!'
      },
      'auth' : {
        'title' : 'Não autorizado',
        'content' : 'Você não tem permissão para acessar essa informação.'
      },
      'inputs' : {
        'btn-positive' : 'Tentar novamente',
        'btn-negative' : 'Cancelar'
      }
    }
  };

  static cleanInit({@required BuildContext context, @required String mainUrl, String messageWhileLoading = 'Loading...'}){
    _progressDialog = new ProgressDialog(context, ProgressDialogType.Normal);
    _progressDialog.setMessage(messageWhileLoading);
    _mainUrl = mainUrl;
  }

  static bool setProgressDialogMessage(String message) {
    if (_progressDialog != null){
      _progressDialog.setMessage(message);
      return true;
    }return false;
  }

  static _setProgressStatus(bool useProgress, bool status){
    if(_progressDialog != null && useProgress){
      if(status)
        _progressDialog.show();
      else
        _progressDialog.hide();
    }
  }

  static bool getProgressDialogStatus(){
    if(_progressDialog != null){
      return _progressDialog.isShowing();
    }return false;
  }

  static setHeader({String contentType = "application/json", String authorization = "bearer"}){
    _header = {"Content-Type": contentType,
      HttpHeaders.authorizationHeader: authorization};
  }

  static setMainUrl(String _url){
    _mainUrl = _url;
  }

  static addGrantedStatusCode(int statusCode){
    _statusSuccess.add(statusCode);
  }

  static String _errorType(errorType type){
    switch(type){
      case errorType.empty: return null;
      case errorType.internet: return 'internet';
      case errorType.auth: return 'auth';
      case errorType.unknown: return 'unknown';
    }

    return null;
  }

  static Future<dynamic> _errorDialog(context, errorType type, data) async =>
      (await showDialog(
          context: context,
          barrierDismissible: false,
          builder: (context) => AlertDialog(
            title: Text(_errors[_language][_errorType(type)]['title']),
            content: Text(_errors[_language][_errorType(type)]['content']),
            actions: <Widget>[
              FlatButton(
                child: Text(_errors[_language]['inputs']['btn-positive']),
                onPressed: () {
                  Navigator.pop(context, {'return' : true});
                },
              ),
              FlatButton(
                child: Text(_errors[_language]['inputs']['btn-negative']),
                onPressed: () {
                  Navigator.pop(context, {'return' : false});
                },
              )
            ],
          )
      ));

  static Future<Rest> _checkWhileError({
                                        @required bool useDialogs,
                                        @required customDialogError,
                                        @required errorType type,
                                        @required data,
                                        @required requestType requestT,
                                        @required String route,
                                        @required BuildContext context,
                                        @required dynamic sBody,
                                        @required String otherMainUrl,
                                        @required bool useProgress,
                                        @required bool jsonDecode,
                                      }) async{

    Rest finalRest = Rest(false, 0, {}, error: type, errorData: data);

    if(useDialogs) {
      if((await customDialogError(type, data))){
        while(finalRest.error != errorType.empty){
          finalRest = await cRequest(type: requestT,
              route: route,
              context: context,
              sBody: sBody,
              otherMainUrl: otherMainUrl,
              useProgress: false,
              useDialogs: false,
              jsonDecode: jsonDecode);

          if(finalRest.error != errorType.empty){
            if(!(await customDialogError(type, data))){
              break;
            }
          }
        }
      }
    }

    return finalRest;
  }

  static Future<Rest> cRequest({
    @required requestType type,
    @required String route,
    @required BuildContext context,
    dynamic sBody,
    String otherMainUrl,
    bool useProgress = true,
    bool useDialogs = true,
    bool jsonDecode = true,
    Future<bool> Function(errorType type, Object data) customDialogError
  }) async{

    Rest finalRest;
    _setProgressStatus(useProgress, true);
    print('init request type ${type.toString()} with route: $_mainUrl$route');
    customDialogError = customDialogError ?? (type, data) async => (await _errorDialog(context, type, data))['return'];

    if(await _checkConn()){
      finalRest = await (_getRequested(otherMainUrl ?? _mainUrl, route, type, sBody)
          .then((response){
            print('success request type ${type.toString()} with route: $_mainUrl$route');

            Rest(_statusSuccess.contains(response.statusCode),
            response.statusCode,
            jsonDecode ? json.decode(response.body) : response.body);
      }).catchError((error) async{
        print('catch request type ${type.toString()} with route: $_mainUrl$route');
        await _checkWhileError(
            useDialogs: useDialogs,
            customDialogError: customDialogError,
            type: errorType.unknown,
            data: error,
            requestT: type,
            route: route,
            context: context,
            sBody: sBody,
            otherMainUrl: otherMainUrl,
            useProgress: useProgress,
            jsonDecode: jsonDecode);
      }
      ));
    }else{
      print('without internet type ${type.toString()} with route: $_mainUrl$route');
      finalRest = await _checkWhileError(useDialogs: useDialogs,
                                          customDialogError: customDialogError,
                                          type: errorType.internet,
                                          data: {},
                                          requestT: type,
                                          route: route,
                                          context: context,
                                          sBody: sBody,
                                          otherMainUrl: otherMainUrl,
                                          useProgress: useProgress,
                                          jsonDecode: jsonDecode);
    }

    _setProgressStatus(useProgress, false);
    return finalRest;
  }

  static Future<Response> _getRequested(_mainUrl, _route, _type, _sBody) async {
    switch (_type) {
      case requestType.get:
        return await get('$_mainUrl$_route', headers: _header);

      case requestType.delete:
        return await delete('$_mainUrl$_route', headers: _header);

      case requestType.post:
        return await post('$_mainUrl$_route', headers: _header, body: json.encode(_sBody));

      case requestType.put:
        return await put('$_mainUrl$_route', headers: _header, body: json.encode(_sBody));

      default: return null;
    }
  }

  static Future<bool> _checkConn() async {
    final connectivityResult = await (Connectivity().checkConnectivity());
    return (connectivityResult == ConnectivityResult.mobile || connectivityResult == ConnectivityResult.wifi);
  }
}

class Rest{
  final bool success;
  final dynamic statusCode;
  final errorType error;
  final Object errorData;
  final dynamic data;

  Rest(this.success, this.statusCode, this.data, {this.error = errorType.empty, this.errorData});

  @override
  String toString() {
    return {'success': success, 'statusCode': statusCode, 'errorType' : error, 'data': data, 'errorData' : errorData}.toString();
  }
}
